// 5648-C84, 5648-C83, (C) Copyright IBM Corporation, 1997, 2000
// All rights reserved. Licensed Materials Property of IBM
// Note to US Government users: Documentation related to restricted rights
// Use, duplication or disclosure is subject to restrictions set forth in GSA ADP Schedule with IBM Corp.
// This page may contain other proprietary notices and copyright information, the terms of which must be observed and followed.
//
// This program may be used, executed, copied, modified and distributed
// without royalty for the purpose of developing, using,
// marketing, or distributing.

/*
 * This is an example servlet that serves as a servlet "front end" to
 * the core SiteOutliner functionality.  This HTTP servlet accepts requests
 * to build or rebuild the site outline (channel), parses the input parameters,
 * and passes this information to the core SiteOutliner class.
 *
 * <p>Refer to SiteOutliner's help file (about.html) for usage information.
 */

package WebSphereSamples.SiteOutliner;

import javax.servlet.*;
import javax.servlet.http.*;
import java.util.*;
import java.net.*;
import java.io.*;
import java.text.*;

/**
  * Example SiteOutlinerServlet-- 
  * This servlet demonstrates a front-end to XML Document Structure Services.
  */
public class SiteOutlinerServlet extends HttpServlet {

   /** 
     * Initialize the servlet when it is first loaded.
     *
     * @param config Instance of class ServletConfig.
     */
   public void init(ServletConfig config)
   throws ServletException
   {
      super.init(config);
   }

   /** 
     * Processes the request to build or rebuild the site's outline (channel).
     *
     * @param req Instance of class HttpServletRequest.
     * @param res Instance of class HttpServletResponse.
     * @exception IOException When inputting form data or writing the data back to the browser.
     */
   public void doGet (HttpServletRequest req, HttpServletResponse res) throws
   ServletException, IOException 
   {

      PrintWriter    out =   null;

      res.setContentType("text/html");
      out = res.getWriter();

      // Write beginning of output document
      out.println("<html><head><title>IBM Site Outliner Output</title></head><body bgcolor=\"navy\" text=\"lime\"><bgsound src=\"/IBMWebAS/samples/SiteOutliner/built.wav\" loop=\"1\">");

      // Set the recursive depth for the SiteOutliner 
      String[] argv = new String[5];
      argv[0] = "-depth";
      String[] paramValues = req.getParameterValues("depth");
      argv[1] = paramValues[0];

      // Run the SiteOutliner in debug mode
      argv[2] = "-debug";

      // Tell the SiteOutliner the server's document root directory
      // argv[3] = context.getRealPath("/");
      argv[3] = this.getServletConfig().getServletContext().getRealPath("/");
      if (argv[3] == null) argv[3] = "/www/html";

      // Tell the SiteOutliner the server's document base URL
      InetAddress host = InetAddress.getLocalHost();
      argv[4] = "http://" + host.getHostAddress();

      // Write out the "starting to build" msg and parameters used
      Date start = new Date();
      out.println("<p>" + start + ":  Building site outline for " + argv[4] + " starting from " + argv[3] + ", scan depth = " + argv[1] + "...<p><pre>");

      // Kick off the core SiteOutliner function
      try {
         SiteOutliner.main(argv);
      } catch (Exception e) {
         out.println(e.getMessage());
         return;
      }

      // Write out the "done building" msg
      Date stop = new Date();
      out.println("</pre><p>" + stop + ":  ...Finished building site outline.");            

      /* Conclude the response document */
      out.println("</body></html>");

   } // end of service

} // end of class


